@@ -7,6 +7,8 @@
 import { errorSerializer, payloadSerializer } from "../../api/serializers";
 import {
   CHANGE_PAGE,
+  clearTimelineInterval,
+  setTimelineInterval,
   SUCCESS as TIMELINE_SUCCESS,
 } from "../../timeline/state/actions";
 import _cloneDeep from "lodash/cloneDeep";
@@ -29,6 +31,8 @@ export const submitComment = (content, format) => {
   return async (dispatch, getState, config) => {
     const { timeline: timelineState } = getState();
 
+    dispatch(clearTimelineInterval());
+
     dispatch({
       type: IS_LOADING,
     });
@@ -60,12 +64,15 @@ export const submitComment = (content, format) => {
           shouldGoToNextPage
         ),
       });
+      dispatch(setTimelineInterval());
     } catch (error) {
       dispatch({
         type: HAS_ERROR,
         payload: errorSerializer(error),
       });
 
+      dispatch(setTimelineInterval());
+
       // throw it again, so it can be caught in the local state
       throw error;
     }
@@ -73,6 +80,7 @@ export const submitComment = (content, format) => {
 };
 
 const _updatedState = (newComment, timelineState, shouldGoToNextPage) => {
+  // return timeline with new comment and pagination logic
   const timelineData = _cloneDeep(timelineState.data);
   const currentHits = timelineData.hits.hits;
 
